# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation

Self = typing.TypeVar('Self')

@typing.final
class BackPressedEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> BackPressedEventArgs: ...
    @_property
    def handled(self) -> bool: ...
    @handled.setter
    def handled(self, value: bool) -> None: ...

@typing.final
class CameraEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CameraEventArgs: ...

@typing.final
class HardwareButtons_Static(type):
    def add_back_pressed(cls, handler: windows_foundation.EventHandler[BackPressedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_back_pressed(cls, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_camera_half_pressed(cls, handler: windows_foundation.EventHandler[CameraEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_camera_half_pressed(cls, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_camera_pressed(cls, handler: windows_foundation.EventHandler[CameraEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_camera_pressed(cls, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_camera_released(cls, handler: windows_foundation.EventHandler[CameraEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_camera_released(cls, token: windows_foundation.EventRegistrationToken, /) -> None: ...

@typing.final
class HardwareButtons(winrt.system.Object, metaclass=HardwareButtons_Static):
    pass




# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import winrt.system
from winrt import _winrt_windows_phone_ui_input

__all__ = [
    "BackPressedEventArgs",
    "CameraEventArgs",
    "HardwareButtons",
]

BackPressedEventArgs = _winrt_windows_phone_ui_input.BackPressedEventArgs
CameraEventArgs = _winrt_windows_phone_ui_input.CameraEventArgs
HardwareButtons = _winrt_windows_phone_ui_input.HardwareButtons
